summaryrefslogtreecommitdiffstats
path: root/src/gui/general/RosegardenCanvasView.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
commit458efa7b0c935cbaafa2791021a5f8f7241aa876 (patch)
tree624583f2873febe23770bee3fa94b5c24bd59f4f /src/gui/general/RosegardenCanvasView.h
parent747037b72944ae2c02962b7c5c96e0a7f8852e38 (diff)
downloadrosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.tar.gz
rosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.zip
Initial TQt4 port of Rosegarden
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1230242 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/general/RosegardenCanvasView.h')
-rw-r--r--src/gui/general/RosegardenCanvasView.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/gui/general/RosegardenCanvasView.h b/src/gui/general/RosegardenCanvasView.h
index 3096334..02faef2 100644
--- a/src/gui/general/RosegardenCanvasView.h
+++ b/src/gui/general/RosegardenCanvasView.h
@@ -43,18 +43,19 @@ namespace Rosegarden
/**
* A TQCanvasView with an auxiliary horiz. scrollbar
* That scrollbar should be provided by the parent widget
* (typically an EditView). The RosegardenCanvasView keeps
* the auxilliary horiz. scrollbar range in sync with the
* one of its own scrollbar with slotUpdate().
*/
-class RosegardenCanvasView : public QCanvasView
+class RosegardenCanvasView : public TQCanvasView
{
Q_OBJECT
+ TQ_OBJECT
public:
RosegardenCanvasView(TQCanvas*,
- TQWidget* parent=0, const char* name=0, WFlags f=0);
+ TQWidget* tqparent=0, const char* name=0, WFlags f=0);
/**
* EditTool::handleMouseMove() returns a OR-ed combination of these
@@ -43,18 +43,19 @@ namespace Rosegarden
/**
* A TQCanvasView with an auxiliary horiz. scrollbar
- * That scrollbar should be provided by the parent widget
+ * That scrollbar should be provided by the tqparent widget
* (typically an EditView). The RosegardenCanvasView keeps
* the auxilliary horiz. scrollbar range in sync with the